==> haskell-parsers-0.12.12-112.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parsers
version:              0.12.12
visibility:           public
id:                   parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT
key:                  parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  676f8400cd5026fea2f863cd2c0d529d
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.6.6/site-local/parsers-0.12.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/parsers-0.12.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/parsers-0.12.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    binary-0.8.9.1 charset-0.3.12-AmjtFvhjrx2JD02c7IN6qm
    containers-0.6.7 mtl-2.3.1 parsec-3.1.16.1
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.12-113-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parsers
version:              0.12.12
visibility:           public
id:                   parsers-0.12.12-PO1r5WusBRCqoNlSszPjk
key:                  parsers-0.12.12-PO1r5WusBRCqoNlSszPjk
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  fddb1a03483618a58dc405515b880503
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.6.6/site-local/parsers-0.12.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/parsers-0.12.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/parsers-0.12.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.12-PO1r5WusBRCqoNlSszPjk
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    binary-0.8.9.1 charset-0.3.12-2D9nY7DBdxY1nhEyRK58pN
    containers-0.6.7 mtl-2.3.1 parsec-3.1.16.1
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
